summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarco d'Itri <md@linux.it>2009-04-12 05:55:21 +0200
committerMarco d'Itri <md@linux.it>2013-03-30 02:31:37 +0100
commitb3164a2b0f56bbba158422ca564bedd9dd0abfb8 (patch)
treecd87766e8645bc874bd5ea589a1e51ed64078bb6
parentba38b34886f25c3448c2215e35220683a5bb7010 (diff)
downloadwhois-b3164a2b0f56bbba158422ca564bedd9dd0abfb8.tar.gz
Imported Debian version 4.7.33v4.7.33
-rw-r--r--config.h33
-rw-r--r--debian/changelog11
-rw-r--r--mkpasswd.c122
-rw-r--r--po/cs.po69
-rw-r--r--po/de.po69
-rw-r--r--po/el.po69
-rw-r--r--po/es.po69
-rw-r--r--po/eu.po69
-rw-r--r--po/fi.po69
-rw-r--r--po/fr.po70
-rw-r--r--po/it.po71
-rw-r--r--po/ja.po69
-rw-r--r--po/no.po69
-rw-r--r--po/pl.po70
-rw-r--r--po/pt_BR.po70
-rw-r--r--po/ru.po69
-rw-r--r--tld_serv_list2
-rw-r--r--whois.spec2
18 files changed, 609 insertions, 463 deletions
diff --git a/config.h b/config.h
index de2af0f..92cade3 100644
--- a/config.h
+++ b/config.h
@@ -1,5 +1,5 @@
/* Program version */
-#define VERSION "4.7.32"
+#define VERSION "4.7.33"
/* Configurable features */
@@ -31,9 +31,9 @@
#endif
/* needs unistd.h */
-#ifdef _ISO_CPP_14882_1998
-/* Solaris 8 and better. What else? */
+#if defined _POSIX_C_SOURCE && _POSIX_C_SOURCE >= 200112L
# define HAVE_GETADDRINFO
+# define HAVE_REGEXEC
#endif
#if defined __APPLE__ && defined __MACH__
@@ -50,10 +50,33 @@
# endif
#endif
-#if defined _POSIX2_VERSION
-# define HAVE_REGEXEC
+/* Unknown versions of Solaris */
+#if defined __SVR4 && defined __sun
+# define HAVE_SHA_CRYPT
#endif
+/* FIXME: which systems lack this? */
+#define HAVE_GETTIMEOFDAY
+
+/*
+ * Please send patches to correctly ignore old releases which lack a RNG
+ * and add more systems which have one.
+ */
+#ifdef RANDOM_DEVICE
+#elif defined __GLIBC__ \
+ || defined __FreeBSD__ || defined __NetBSD__ || defined __OpenBSD__ \
+ /* AIX >= 5.2? */ \
+ || defined _AIX52 \
+ /* HP-UX >= B.11.11.09? */ \
+ || defined __hpux \
+ /* OS X: */ \
+ || (defined __APPLE__ && defined __MACH__) \
+ /* Solaris >= 9 (this is >= 7): */ \
+ || (defined __SVR4 && defined __sun && defined SUSv2) \
+ /* Tru64 UNIX >= 5.1B? */ \
+ || defined __osf
+# define RANDOM_DEVICE "/dev/urandom"
+#endif
#ifdef ENABLE_NLS
# ifndef NLS_CAT_NAME
diff --git a/debian/changelog b/debian/changelog
index 780d834..318ca27 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,14 @@
+whois (4.7.33) unstable; urgency=medium
+
+ * mkpasswd: use /dev/urandom to generate the salt. If it is not present,
+ initialize srand(3) with gettimeofday(2) instead of time(2) to have a
+ larger randomness space. (Closes: #523387)
+ * mkpasswd: added preliminary support for variable length salts, patch
+ courtesy of Nicolas François.
+ * Updated the .co.za SLD server. (Closes: #521579)
+
+ -- Marco d'Itri <md@linux.it> Sun, 12 Apr 2009 05:55:21 +0200
+
whois (4.7.32) unstable; urgency=medium
* Added new ASN allocations.
diff --git a/po/cs.po b/po/cs.po
index 33cee53..7ee5867 100644
--- a/po/cs.po
+++ b/po/cs.po
@@ -5,7 +5,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.7.26\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2008-07-01 09:40+0200\n"
"Last-Translator: Petr Pisar <petr.pisar@atlas.cz>\n"
"Language-Team: Czech <translation-team-cs@lists.sourceforge.net>\n"
@@ -13,7 +13,7 @@ msgstr ""
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -25,33 +25,33 @@ msgstr ""
"Chyby programu hlaste na %s (anglicky), chyby překladu na\n"
"<translation-team-cs@lists.sourceforge.net> (česky).\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Používám server %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Tato TLD nemá žádný whoisový server, ale k whoisové databázi se lze dostat na"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Tato TLD nemá žádný whoisový server."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Pro tento druh objektu není znám žádný whoisový server."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr ""
"Neznémé číslo AS nebo neznámá IP síť.\n"
"Prosím, pořiďte si novou verzi tohoto programu."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -62,7 +62,7 @@ msgstr ""
"Dotazuji se na IPv4 konec %s příslušející 6to4 IPv6 adrese.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, c-format
msgid ""
"\n"
@@ -73,7 +73,7 @@ msgstr ""
"Dotazuji se na IPv4 konec %s příslušející Teredo IPv6 adrese.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -82,7 +82,7 @@ msgstr ""
"Znění dotazu: „%s“\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -95,16 +95,16 @@ msgstr ""
"Nalezen odkaz na %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Tento řádek nemohu rozebrat: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Varování: RIPE příznak použit s tradičním serverem."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -112,26 +112,26 @@ msgstr ""
"Katastrofální chyba: text prohlášení byl pozměněn.\n"
"Prosím, pořiďte si novou verzi tohoto programu.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Jméno počítače %s nenalezeno."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/TCP: neznámá služba"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Čas vypršel."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Přerušeno signálem %d…"
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -200,51 +200,56 @@ msgstr ""
" --help zobrazí tuto nápovědu a skončí\n"
" --version vypíše informace o verzi a skončí\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
msgid "standard 56 bit DES-based crypt(3)"
msgstr "standardní crypt(3) založený na 56bitové šifře DES"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, c-format
msgid "Invalid method '%s'.\n"
msgstr "Neplatná metoda „%s“.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Neplatné číslo „%s“.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Pro podrobnosti zkuste příkaz „%s --help“.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Chybná délka soli: %d bajty(ů), zatímco očekáváno %d.\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Chybná délka soli: %d bajty(ů), zatímco očekáváno %d.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Neplatný znak v soli „%c“.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Heslo: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Zakázaný znak v hesle „0x%hhx“.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr "Metoda není podporována funkcí crypt(3).\n"
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -255,7 +260,7 @@ msgstr ""
"Zašifruje HESLO pomocí funkce crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -289,7 +294,7 @@ msgstr ""
"Chyby programu hlaste na %s (anglicky), chyby překladu na\n"
"<translation-team-cs@lists.sourceforge.net> (česky).\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, c-format
msgid "Available methods:\n"
msgstr "Dostupné metody:\n"
diff --git a/po/de.po b/po/de.po
index 3e02caa..ef84f04 100644
--- a/po/de.po
+++ b/po/de.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.6.16\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2004-06-15 00:08+0100\n"
"Last-Translator: Adrian Bunk <bunk@fs.tum.de>\n"
"Language-Team: \n"
@@ -15,7 +15,7 @@ msgstr ""
"Content-Type: text/plain; charset=iso-8859-1\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -26,31 +26,31 @@ msgstr ""
"\n"
"Senden Sie Bugreports an %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Benutze Server %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr "Diese TLD hat keinen whois-Server, aber eine whois-Datenbank unter"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Diese TLD hat keinen whois-Server."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Hierfr ist kein Whois-Server bekannt."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr ""
"Unbekannte AS- oder IP-Netzwerk-Nummer. Bitte upgraden Sie dieses Programm."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -61,7 +61,7 @@ msgstr ""
"Frage nach dem IPv4 Endpunkt %s einer 6to4 IPv6-Adresse.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, fuzzy, c-format
msgid ""
"\n"
@@ -72,7 +72,7 @@ msgstr ""
"Frage nach dem IPv4 Endpunkt %s einer 6to4 IPv6-Adresse.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -81,7 +81,7 @@ msgstr ""
"Suche nach: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -94,17 +94,17 @@ msgstr ""
"Verweis auf %s gefunden.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Kann diese Zeile nicht parsen: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr ""
"Warnung: RIPE-Flags wurden mit einem \"traditionellen\" Server verwendet."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -112,26 +112,26 @@ msgstr ""
"Schwerer Fehler: Haftungsausschlusstext wurde geaendert.\n"
"Bitte upgraden sie dieses Programm.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Host %s nicht gefunden."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: unbekannter Dienst"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Timeout."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Erhielt Signal %d, unterbrochen..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, fuzzy, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -197,52 +197,57 @@ msgstr ""
" --help zeige diese Hilfe\n"
" --version zeige Version\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
#, fuzzy
msgid "standard 56 bit DES-based crypt(3)"
msgstr "\tStandard 56 Bit DES-basiertes crypt(3)"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, fuzzy, c-format
msgid "Invalid method '%s'.\n"
msgstr "Falsche Nummer '%s'.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Falsche Nummer '%s'.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Versuchen Sie '%s --help' fr mehr Informationen.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Falsche Salt-Lnge: %d Byte(s), aber%d wurden erwartet.\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Falsche Salt-Lnge: %d Byte(s), aber%d wurden erwartet.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Illegaler Salt-Buchstabe '%c'.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Passwort:"
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Illegaler Passwort-Buchstabe '0x%hhx'.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -253,7 +258,7 @@ msgstr ""
"Verschluesselt das PASSWORT mit crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -272,7 +277,7 @@ msgid ""
"Report bugs to %s.\n"
msgstr ""
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, fuzzy, c-format
msgid "Available methods:\n"
msgstr "Verfgbare Algorithmen:\n"
diff --git a/po/el.po b/po/el.po
index 6fad1a7..604d323 100644
--- a/po/el.po
+++ b/po/el.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.6.9\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2003-12-10 08:51+0200\n"
"Last-Translator: Velonis Petros <velonis@freemail.gr>\n"
"Language-Team: Greek <velonis@freemail.gr>\n"
@@ -14,7 +14,7 @@ msgstr ""
"Content-Type: text/plain; charset=utf-8\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -25,35 +25,35 @@ msgstr ""
"\n"
"Αναφέρατε σφάλματα στο %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Γίνεται χρήση του εξυπηρετητή %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Αυτό το TLD δεν έχει εξυπηρετητή whois, ωστόσο μπορείτε να προσπελάσετε την "
"βάση whois στο"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Αυτό το TLD δεν έχει εξυπηρετητή whois."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr ""
"Κανένας εξυπηρετητής whois δεν είναι γνωστός για αυτού του είδους το "
"αντικείμενο."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr ""
"Άγνωστος αριθμός AS ή IP δικτύου. Παρακαλώ αναβαθμίστε αυτό το πρόγραμμα."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -64,7 +64,7 @@ msgstr ""
"Άντληση πληροφοριών για το σημείο τέλους IPv4 %s μιας διεύθυνσης 6to4 IPv6.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, fuzzy, c-format
msgid ""
"\n"
@@ -75,7 +75,7 @@ msgstr ""
"Άντληση πληροφοριών για το σημείο τέλους IPv4 %s μιας διεύθυνσης 6to4 IPv6.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -84,7 +84,7 @@ msgstr ""
"Αλφαριθμητικό ερώτησης: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -97,18 +97,18 @@ msgstr ""
"Βρέθηκε αναφορά στο %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Αδύνατη η ανάλυση αυτής της γραμμής: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr ""
"Προειδοποίηση: Η σημαίες του RIPE χρησιμοποιούνται σε έναν παραδοσιακό "
"εξυπηρετητή."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -116,26 +116,26 @@ msgstr ""
"Καταστροφικό σφάλμα: το κείμενο της αποποίησης ευθυνών έχει τροποποιηθεί.\n"
"Παρακαλώ αναβαθμίστε το πρόγραμμα.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Το σύστημα %s δε βρέθηκε."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: άγνωστη υπηρεσία"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Διάλειμμα."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Διακοπή από το σήμα %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -209,52 +209,57 @@ msgstr ""
" --help εμφάνιση αυτής της βοήθειας και έξοδος\n"
" --version εμφάνιση της έκδοσης και έξοδος\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
#, fuzzy
msgid "standard 56 bit DES-based crypt(3)"
msgstr "\tκαθεριερωμένη 56 bit με βάση το DES crypt(3)"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, fuzzy, c-format
msgid "Invalid method '%s'.\n"
msgstr "Μη αποδεκτό νούμερο '%s'.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Μη αποδεκτό νούμερο '%s'.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Προσπάθησε '%s --help' για περισσότερες πληροφορίες.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Εσφαλμένο μήκος salt : %d byte(s) όταν αναμένεται %d .\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Εσφαλμένο μήκος salt : %d byte(s) όταν αναμένεται %d .\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Μη αποδεκτός χαρακτήρας salt '%c'.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Συνθηματικό: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Μη αποδεκτός χαρακτήρας συνθηματικού '0x%hhx'.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -265,7 +270,7 @@ msgstr ""
"Κρυπτογραφεί το ΣΥΝΘΗΜΑΤΙΚΟ χρησιμοποιώντας το crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, fuzzy, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -298,7 +303,7 @@ msgstr ""
"\n"
"Αναφέρατε σφάλματα στο %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, fuzzy, c-format
msgid "Available methods:\n"
msgstr "Διαθέσιμοι αλγόριθμοι:\n"
diff --git a/po/es.po b/po/es.po
index d9100d9..e0651f4 100644
--- a/po/es.po
+++ b/po/es.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.5.29\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2002-08-24 16:22+0200\n"
"Last-Translator: Francisco Monteagudo <francisco@monteagudo.net>\n"
"Language-Team: Spanish <es@li.org>\n"
@@ -14,7 +14,7 @@ msgstr ""
"Content-Type: text/plain; charset=iso-8859-1\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -25,33 +25,33 @@ msgstr ""
"\n"
"Informar de bugs a %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Usando el servidor %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Este TLD no dispone de servidor whois, pero puede acceder a la informacion "
"de whois en"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "No existe servidor whois para este TLD."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr ""
-#: ../whois.c:220
+#: ../whois.c:223
#, fuzzy
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "Numero AS desconocido. Por favor, actualice este programa."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -59,7 +59,7 @@ msgid ""
"\n"
msgstr ""
-#: ../whois.c:257
+#: ../whois.c:260
#, c-format
msgid ""
"\n"
@@ -67,7 +67,7 @@ msgid ""
"\n"
msgstr ""
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -76,7 +76,7 @@ msgstr ""
"Consulta: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, fuzzy, c-format
msgid ""
"\n"
@@ -88,18 +88,18 @@ msgstr ""
"Se ha encontrado en crsnic una referencia a %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "No puedo procesar esta linea: %s"
-#: ../whois.c:482
+#: ../whois.c:489
#, fuzzy
msgid "Warning: RIPE flags used with a traditional server."
msgstr ""
"Atencion: Los flags RIPE son ignorados por los servidores tradicionales."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -107,26 +107,26 @@ msgstr ""
"Error catastrofico: el texto de las condiciones de uso ha sido cambiado.\n"
"Actualize este programa.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Host %s no encontrado."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: servicio desconocido"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr ""
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Interrumpido por la seal %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, fuzzy, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -194,52 +194,57 @@ msgstr ""
" --help muestra esta pantalla de ayuda y finaliza\n"
" --version muestra la version del programa y finaliza\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
#, fuzzy
msgid "standard 56 bit DES-based crypt(3)"
msgstr "\tcrypt(3) basado en DES de 56 bits"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, fuzzy, c-format
msgid "Invalid method '%s'.\n"
msgstr "El numero '%s' no es valido.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "El numero '%s' no es valido.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "%s --help para mas informacion.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Tamao de semilla incorrecto: %d bytes en lugar de %d.\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Tamao de semilla incorrecto: %d bytes en lugar de %d.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "El caracter '%c' ilegal en la semilla.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Clave: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "El caracter '0x%hhx' es ilegal en la clave.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -250,7 +255,7 @@ msgstr ""
"Encripta CLAVE utilizando crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, fuzzy, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -282,7 +287,7 @@ msgstr ""
"\n"
"Informar de bugs a: %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, fuzzy, c-format
msgid "Available methods:\n"
msgstr "Algoritmos disponibles:\n"
diff --git a/po/eu.po b/po/eu.po
index 8385abc..bba3a8a 100644
--- a/po/eu.po
+++ b/po/eu.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.5.29\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2002-08-24 16:22+0200\n"
"Last-Translator: Aitor Ibaez <aitiba@gmail.com>\n"
"Language-Team: Euskara <Librezale@librezale.org>\n"
@@ -15,7 +15,7 @@ msgstr ""
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -26,33 +26,33 @@ msgstr ""
"\n"
"Bug berri baten jakinarazpena: %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "%s zerbitzaria erabiltzen.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"TLD honek ez du whois zerbitzaririk, baina whois databasera sarbidea "
"daukazu..."
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "TLD honek ez du whois zerbitzaririk."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Objetu mota horrentzako, ez da whois zerbitzaririk ezagutzen."
-#: ../whois.c:220
+#: ../whois.c:223
#, fuzzy
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "AS zenbaki edo IP sarea ezezaguna. Mesedez, programa eguneratu."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -63,7 +63,7 @@ msgstr ""
"Kontsula 6to4 IPv6 helbidean dagoen %s IPv4 endpoint-entzat.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, fuzzy, c-format
msgid ""
"\n"
@@ -74,7 +74,7 @@ msgstr ""
"Kontsula 6to4 IPv6 helbidean dagoen %s IPv4 endpoint-entzat.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -83,7 +83,7 @@ msgstr ""
"Kontsulta: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, fuzzy, c-format
msgid ""
"\n"
@@ -95,17 +95,17 @@ msgstr ""
"$s-ra erreferentzia aurkituta.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Lerro hau, %s , ezin da prozesatu."
-#: ../whois.c:482
+#: ../whois.c:489
#, fuzzy
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Oharra: RIPE flags-ak ohiko zerbitzariengatik ezikusiak izaten dira."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -113,26 +113,26 @@ msgstr ""
"Hondamen arriskua: erabilpen balditzen textua aldatu egin da.\n"
"Programa eguneratu.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "%s Host-a ez da aurkitu."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: zerbitzu ezezaguna"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Denbora muga."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "%d seinalearengatik etena..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, fuzzy, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -203,52 +203,57 @@ msgstr ""
" --help laguntza pantaila hau erakusten du eta amaitzen du\n"
" --version programaren bertsioa erakusten du eta amaitzen du\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
#, fuzzy
msgid "standard 56 bit DES-based crypt(3)"
msgstr "56 bits-etako DESan oinarritutako \tcrypt(3)-a"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, fuzzy, c-format
msgid "Invalid method '%s'.\n"
msgstr "'%s' zenbakia ez da baliozkoa.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "'%s' zenbakia ez da baliozkoa.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "%s --help informazio gehiagorako.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Hazi tamain desegokia:%d byte %d-en ordez.\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Hazi tamain desegokia:%d byte %d-en ordez.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "'%c' karakterea, hazian, ilegala da.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Pasahitza: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "'0x%hhx' password karakterea ilegala da.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -259,7 +264,7 @@ msgstr ""
"PASAHITZA crypt(3) erabiliz enkriptatu.\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, fuzzy, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -292,7 +297,7 @@ msgstr ""
"\n"
"Bug berri baten jakinarazpena: %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, fuzzy, c-format
msgid "Available methods:\n"
msgstr "Algoritmo erabilgarriak:\n"
diff --git a/po/fi.po b/po/fi.po
index e308892..51bc064 100644
--- a/po/fi.po
+++ b/po/fi.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.7.28\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2008-09-28 19:28+0100\n"
"Last-Translator: Sami Kerola <kerolasa@iki.fi>\n"
"Language-Team: \n"
@@ -14,7 +14,7 @@ msgstr ""
"Content-Type: text/plain; charset=iso-8859-1\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -25,31 +25,31 @@ msgstr ""
"\n"
"Lhet bugiraportit osoitteeseen %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Kytetn palvelinta %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Tlla TLD:ll ei ole whois palvelinta, tiedot ovat nakyviss osoitteessa"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Tlla TLD:ll ei ole whois palvelinta."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Kysytty ei vastaa minkaan whois palvelun tietmiin tietoihin."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "Tuntematon AS-numero tai IP-verkko. Pivit tm ohjelma."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -60,7 +60,7 @@ msgstr ""
"Kysytn IPv4 ulostulona %s IPv6:n IPv4 avaruudesta.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, c-format
msgid ""
"\n"
@@ -71,7 +71,7 @@ msgstr ""
"Kysytn IPv4 ulostulona %s Teredo IPv6 tunneliosoitetta.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -80,7 +80,7 @@ msgstr ""
"Kysely: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -93,16 +93,16 @@ msgstr ""
"Lytyi viittaus %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Ohjelma ei kykene tulkitsemaan rivi: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Varoitus: kytt RIPE valitsimia traditionaaliseen palvelimeen."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -110,26 +110,26 @@ msgstr ""
"Katastrofaalinen virhe: lisenssiteksti on muuttunut.\n"
"Pivita ohjelma.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Palvelinta %s ei lydy."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: tuntematon versio"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Aikakatkaisu."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Ohjelma keskeytyi signaaliin %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -195,51 +195,56 @@ msgstr ""
" --help tulosta tm ruutu\n"
" --version tulosta versio\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
msgid "standard 56 bit DES-based crypt(3)"
msgstr "\tStandardi DES-salaus ks crypt(3)"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, c-format
msgid "Invalid method '%s'.\n"
msgstr "Vr metodi '%s'.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Vr numero '%s'.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Kyt valitsinta '%s --help' listietojen saamiseen.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Vr suolan pituus: %d tavu(a), kun %d tavua odotettiin.\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Vr suolan pituus: %d tavu(a), kun %d tavua odotettiin.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Suolassa laiton merkki '%c'.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Salasana:"
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Laiton merkki salasanassa '0x%hhx'.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr "Toiminto ei ole tuettu crypt(3) funktiossa.\n"
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -250,7 +255,7 @@ msgstr ""
"Salaa salasanan crypt(3) funktiolla.\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -283,7 +288,7 @@ msgstr ""
"\n"
"Lhet bugiraportit osoitteeseen %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, c-format
msgid "Available methods:\n"
msgstr "Kytettviss olevat toiminnot:\n"
diff --git a/po/fr.po b/po/fr.po
index 093acb0..cdd36b2 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -6,7 +6,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.6.5\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2008-03-25 20:16+0100\n"
"Last-Translator: Simon Paillard <simon.paillard@resel.enst-bretagne.fr>\n"
"Language-Team: French <debian-l10n-french@lists.debian.org>\n"
@@ -14,7 +14,7 @@ msgstr ""
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -25,32 +25,32 @@ msgstr ""
"\n"
"Veuillez signaler les bogues à %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Le serveur %s est sélectionné.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Ce TLD n'a pas de serveur whois, mais vous pouvez accéder à la base de "
"données à"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Ce TLD n'a pas de serveur whois."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Aucun serveur whois n'est connu pour ce type d'objet."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "Numéro d'AS ou réseau IP inconnu. Veuillez mettre à jour ce programme."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -61,7 +61,7 @@ msgstr ""
"Requête faite pour l'extrémité IPv4 %s d'une adresse IPv6 6to4.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, c-format
msgid ""
"\n"
@@ -72,7 +72,7 @@ msgstr ""
"Requête faite pour l'extrémité IPv4 %s d'une adresse IPv6 6to4.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -81,7 +81,7 @@ msgstr ""
"Requête : \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -94,17 +94,17 @@ msgstr ""
"Renvoi trouvé vers %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Impossible d'interpréter la ligne : %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr ""
"Avertissement : des options RIPE ont été utilisées avec un serveur classique."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -112,26 +112,26 @@ msgstr ""
"Erreur catastrophique : le texte de déni de responsabilité a changé.\n"
"Veuillez mettre à jour ce programme.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "L'hôte %s est introuvable."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: service inconnu"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Temps limite dépassé."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Interruption par le signal %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -208,52 +208,58 @@ msgstr ""
" --help afficher cette page d'aide et sortir\n"
" --version afficher les informations de version et sortir\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
msgid "standard 56 bit DES-based crypt(3)"
msgstr "fonction crypt(3) standard, chiffrement DES à 56 bits"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, c-format
msgid "Invalid method '%s'.\n"
msgstr "La méthode '%s' est invalide.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Le nombre '%s' est invalide.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Veuillez taper '%s --help' pour plus d'informations.\n"
# : ../mkpasswd.c:152
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Mauvaise taille d'aléa: %d octet(s) au lieu de %d.\n"
-#: ../mkpasswd.c:231
+# : ../mkpasswd.c:152
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Mauvaise taille d'aléa: %d octet(s) au lieu de %d.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Le caractère '%c' est invalide dans l'aléa.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Mot de passe : "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Le caractère '0x%hhx' est invalide dans le mot de passe.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr "Méthode non prise en charge par crypt(3).\n"
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -264,7 +270,7 @@ msgstr ""
"Chiffre le MOT DE PASSE à l'aide de la fonction crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -298,7 +304,7 @@ msgstr ""
"\n"
"Veuillez signaler les bogues à %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, c-format
msgid "Available methods:\n"
msgstr "Méthodes disponibles :\n"
diff --git a/po/it.po b/po/it.po
index d012dd6..d3b5f70 100644
--- a/po/it.po
+++ b/po/it.po
@@ -5,15 +5,15 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.7.14\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
-"PO-Revision-Date: 2006-07-15 19:18+0200\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
+"PO-Revision-Date: 2009-04-12 06:04+0200\n"
"Last-Translator: Marco d'Itri <md@linux.it>\n"
"Language-Team: Italian <tp@lists.linux.it>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=iso-8859-1\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -24,32 +24,32 @@ msgstr ""
"\n"
"Segnalare i bug a %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Uso il server %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Questo TLD non ha un server whois, ma si pu accedere al database tramite"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Per questo TLD non esiste un server whois."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Non noto alcun server whois per questo tipo di oggetto."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr ""
"Numero dell'AS o della rete IP sconosciuto. Per favore aggiorna il programma."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -60,7 +60,7 @@ msgstr ""
"Cerco l'endpoint IPv4 %s di un indirizzo IPv6 6to4.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, c-format
msgid ""
"\n"
@@ -71,7 +71,7 @@ msgstr ""
"Cerco l'endpoint IPv4 %s di un indirizzo IPv6 Teredo.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -80,7 +80,7 @@ msgstr ""
"Richiesta: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -93,16 +93,16 @@ msgstr ""
"Trovato un riferimento a %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Impossibile interpretare questa riga: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Attenzione: sono stati usati dei flag RIPE con un server tradizionale."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -110,26 +110,26 @@ msgstr ""
"Errore catastrofico: il testo di avvertenze cambiato.\n"
"Aggiorna questo programma.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Host %s non trovato."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: servizio sconosciuto"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Tempo scaduto."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Interrotto dal segnale %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -198,51 +198,56 @@ msgstr ""
" --help mostra questo aiuto ed esce\n"
" --version stampa le informazioni sulla versione ed esce\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
msgid "standard 56 bit DES-based crypt(3)"
msgstr "crypt(3) standard a 56 bit basata su DES"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, c-format
msgid "Invalid method '%s'.\n"
msgstr "Il metodo '%s' non valido.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Il numero '%s' non valido.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Per maggior informazioni prova '%s --help'.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Lunghezza del sale sbagliata: %d byte invece di %d.\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Lunghezza del sale sbagliata: %d byte invece di %d <= n <= %d.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Il carattere '%c' non valido in un sale.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Password: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Il carattere '0x%hhx' non valido in una password.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr "Metodo non gestito da crypt(3).\n"
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -253,7 +258,7 @@ msgstr ""
"Cifra la PASSWORD usando crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -286,7 +291,7 @@ msgstr ""
"\n"
"Segnalare i bug a %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, c-format
msgid "Available methods:\n"
msgstr "Metodi disponibili:\n"
diff --git a/po/ja.po b/po/ja.po
index 68329f9..c6a520a 100644
--- a/po/ja.po
+++ b/po/ja.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.7.2\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2005-04-26 00:20+0900\n"
"Last-Translator: Satoru SATOH <ss@gnome.gr.jp>\n"
"Language-Team: Japanese <gnome-translation@gnome.gr.jp>\n"
@@ -15,7 +15,7 @@ msgstr ""
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -26,32 +26,32 @@ msgstr ""
"\n"
"バグ報告は %s へ.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "サーバー %s を使用\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"この TLD には whois サーバーがありませんが、次のサーバーで whois データベース"
"にアクセスできます"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "この TLD には whois サーバーがありません"
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "この種のオブジェクトに対する既知の whois サーバーはありません"
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "不明な AS 番号または IP ネットワーク. アップグレードして下さい"
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -62,7 +62,7 @@ msgstr ""
"6to4 IPv6 アドレスの IPv4 終端 %s を問い合わせ中\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, fuzzy, c-format
msgid ""
"\n"
@@ -73,7 +73,7 @@ msgstr ""
"6to4 IPv6 アドレスの IPv4 終端 %s を問い合わせ中\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -82,7 +82,7 @@ msgstr ""
"問い合わせ文字列: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -95,16 +95,16 @@ msgstr ""
"%s への照会をみつけました\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "この行を解析できません: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr "警告: 旧来のサーバーについて RIPE フラグが使用されています"
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -112,26 +112,26 @@ msgstr ""
"破滅的なエラー: 免責条項テキストが変更されました\n"
"このプログラムをアップグレードして下さい\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "ホスト %s はみつかりませんでした"
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: 不明なサービス"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "時間切れ"
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "シグナル %d が割込み..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -197,52 +197,57 @@ msgstr ""
" --help このヘルプを表示して終了\n"
" --version バージョン情報を表示して終了\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
#, fuzzy
msgid "standard 56 bit DES-based crypt(3)"
msgstr "\t標準 56 ビット DES ベース暗号(3)"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, fuzzy, c-format
msgid "Invalid method '%s'.\n"
msgstr "不正な数字 '%s'\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "不正な数字 '%s'\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "さらなる詳細については '%s --help' を実行\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "間違ったソルト長: %d バイト(s) (%d を期待)\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "間違ったソルト長: %d バイト(s) (%d を期待)\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "不正なソルト文字 '%c'\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "パスワード: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "不正なパスワード文字 '0x%hhx'\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -253,7 +258,7 @@ msgstr ""
"PASSWORD を crypt(3) で暗号化\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, fuzzy, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -285,7 +290,7 @@ msgstr ""
"\n"
"バグ報告は %s へ.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, fuzzy, c-format
msgid "Available methods:\n"
msgstr "利用可能なアルゴリズム:\n"
diff --git a/po/no.po b/po/no.po
index d4d354d..4ae1860 100644
--- a/po/no.po
+++ b/po/no.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.4.5\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 1999-12-18 14:00:00\n"
"Last-Translator: Egil Kvaleberg <egil@kvaleberg.no>\n"
"Language-Team: Norwegian <no@li.org>\n"
@@ -15,7 +15,7 @@ msgstr ""
"Content-Type: text/plain; charset=iso-8859-1\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -23,31 +23,31 @@ msgid ""
"Report bugs to %s.\n"
msgstr ""
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Bruker tjener %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr ""
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr ""
-#: ../whois.c:220
+#: ../whois.c:223
#, fuzzy
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "Ukjent AS-nummer. Vennligst oppdater programmet."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -55,7 +55,7 @@ msgid ""
"\n"
msgstr ""
-#: ../whois.c:257
+#: ../whois.c:260
#, c-format
msgid ""
"\n"
@@ -63,7 +63,7 @@ msgid ""
"\n"
msgstr ""
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -72,7 +72,7 @@ msgstr ""
"Foresprsel: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, fuzzy, c-format
msgid ""
"\n"
@@ -84,17 +84,17 @@ msgstr ""
"Fant InterNIC-referanse til %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr ""
-#: ../whois.c:482
+#: ../whois.c:489
#, fuzzy
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Merk: RIPE-flaggene ignoreres for en tradisjonell tjener."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
#, fuzzy
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
@@ -103,26 +103,26 @@ msgstr ""
"Alvorlig feil: INTERNIC har endret standardtekst.\n"
"Vennligst oppdater programmet.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Finner ikke verten %s."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: ukjent port"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr ""
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Avbrudt av signal %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, fuzzy, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -181,51 +181,56 @@ msgstr ""
"\n"
"Versjon %s. Rapporter feil til %s.\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
msgid "standard 56 bit DES-based crypt(3)"
msgstr ""
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, c-format
msgid "Invalid method '%s'.\n"
msgstr ""
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr ""
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr ""
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr ""
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr ""
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr ""
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr ""
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr ""
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -233,7 +238,7 @@ msgid ""
"\n"
msgstr ""
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -252,7 +257,7 @@ msgid ""
"Report bugs to %s.\n"
msgstr ""
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, c-format
msgid "Available methods:\n"
msgstr ""
diff --git a/po/pl.po b/po/pl.po
index e15fbf0..ab53804 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.7.26\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2008-05-18 19:40+0200\n"
"Last-Translator: Jakub Bogusz <qboosh@pld-linux.org>\n"
"Language-Team: Polish <translation-team-pl@lists.sourceforge.net>\n"
@@ -15,7 +15,7 @@ msgstr ""
"Content-Type: text/plain; charset=iso-8859-2\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -26,31 +26,31 @@ msgstr ""
"\n"
"Bdy prosz zgasza na adres %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Uycie serwera %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Ta gwna domena nie ma serwera whois, ale mona uy bazy danych whois pod"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Ta gwna domena nie ma serwera whois."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Dla tego rodzaju obiektu nie jest znany aden serwer whois."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "Nieznany numer AS lub sie IP. Prosz uaktualni ten program."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -61,7 +61,7 @@ msgstr ""
"Pytanie o zakoczenie IPv4 %s adresu IPv6 typu 6to4.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, c-format
msgid ""
"\n"
@@ -72,7 +72,7 @@ msgstr ""
"Pytanie o zakoczenie IPv4 %s adresu IPv6 Teredo.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -81,7 +81,7 @@ msgstr ""
"Zapytanie: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -94,16 +94,16 @@ msgstr ""
"Znaleziono odniesienie do %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Nie mona przeanalizowa tej linii: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Uwaga: uyto flag RIPE ze starszym serwerem."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -111,26 +111,26 @@ msgstr ""
"Katastrofa! Tekst owiadczenia zosta zmieniony.\n"
"Prosz uaktualni ten program.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Serwer %s nie zosta znaleziony."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: usuga nieznana"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Upyn limit czasu."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Przerwano sygnaem %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -204,52 +204,58 @@ msgstr ""
" --version wywietlenie informacji o wersji i zakoczenie "
"dziaania\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
msgid "standard 56 bit DES-based crypt(3)"
msgstr "standardowa 56-bitowa, oparta o DES funkcja crypt(3)"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, c-format
msgid "Invalid method '%s'.\n"
msgstr "Nieprawidowa metoda '%s'.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Nieprawidowa liczba '%s'.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "'%s --help' poda wicej informacji.\n"
# : ../mkpasswd.c:152
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Bdna dugo zarodka: %d bajtw kiedy oczekiwano %d.\n"
-#: ../mkpasswd.c:231
+# : ../mkpasswd.c:152
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Bdna dugo zarodka: %d bajtw kiedy oczekiwano %d.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Bdny znak zarodka '%c'.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Haso: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Bdny znak w hale '0x%hhx'.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr "Metoda nie obsugiwana przez crypt(3).\n"
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -260,7 +266,7 @@ msgstr ""
"Koduje HASO przy uyciu funkcji crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -294,7 +300,7 @@ msgstr ""
"\n"
"Bdy prosz zgasza na adres %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, c-format
msgid "Available methods:\n"
msgstr "Dostpne metody:\n"
diff --git a/po/pt_BR.po b/po/pt_BR.po
index 558080a..3024bfb 100644
--- a/po/pt_BR.po
+++ b/po/pt_BR.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: whois 4.7.5\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2006-04-26 21:03-0300\n"
"Last-Translator: Anderson Goulart <globalx@gmail.com>\n"
"Language-Team: Portuguese/Brazil\n"
@@ -15,7 +15,7 @@ msgstr ""
"Content-Type: text/plain; charset=iso-8859-1\n"
"Content-Transfer-Encoding: 8bit\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -26,32 +26,32 @@ msgstr ""
"\n"
"Reporte bugs para %s \n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Utilizando servidor %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Este TLD no tem servidor whois, mas voc pode acessar a base de dados do "
"whois em"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "No existe servidor whois para este TLD."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Nenhum servidor whois conhecido para este tipo de objeto."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "Nmero AS ou rede IP desconhecidos. Por favor, atualize este programa."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -62,7 +62,7 @@ msgstr ""
"Procurando pela extremidade IPv4 %s de um endereo IPv6. 6to4.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, fuzzy, c-format
msgid ""
"\n"
@@ -73,7 +73,7 @@ msgstr ""
"Procurando pela extremidade IPv4 %s de um endereo IPv6. 6to4.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -82,7 +82,7 @@ msgstr ""
"Consulta: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -95,16 +95,16 @@ msgstr ""
"Uma referncia para%s encontrada.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "No pde processar esta linha: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Aviso: RIPE flags utilizados com um servidor tradicional."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -112,26 +112,26 @@ msgstr ""
"Erro catastrfico: o texto das condies de uso foi alterado.\n"
"Por favor, atualize este programa. \n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Host %s no encontrado."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: servio desconhecido"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Tempo esgotado."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Interrompido pelo sinal %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -202,53 +202,59 @@ msgstr ""
" --help exibe essa ajuda e sai\n"
" --version exibe informaes sobre a verso e sai\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
#, fuzzy
msgid "standard 56 bit DES-based crypt(3)"
msgstr "\tstandard 56 bit DES-based crypt(3)"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, fuzzy, c-format
msgid "Invalid method '%s'.\n"
msgstr "Nmero invlido '%s'.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Nmero invlido '%s'.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Tente '%s --help para maiores informaes.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr ""
"Tamanho do salt incorreto: %d byte(s) enquanto %d era(m) esperado(s).\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr ""
+"Tamanho do salt incorreto: %d byte(s) enquanto %d era(m) esperado(s).\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Caractere salt ilegal '%c'.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Senha: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Caractere de senha ilegal '0x%hhx'.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -259,7 +265,7 @@ msgstr ""
"Encripta a PASSWORD utilizando crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, fuzzy, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -291,7 +297,7 @@ msgstr ""
"\n"
"Reporte bugs para %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, fuzzy, c-format
msgid "Available methods:\n"
msgstr "Algoritmos disponveis: \n"
diff --git a/po/ru.po b/po/ru.po
index fbf1583..62a1023 100644
--- a/po/ru.po
+++ b/po/ru.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: ru\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2008-12-09 02:03+0100\n"
+"POT-Creation-Date: 2009-04-12 06:00+0200\n"
"PO-Revision-Date: 2005-11-29 15:15+0200\n"
"Last-Translator: Andy Shevchenko <andy@smile.org.ua>\n"
"Language-Team: Russian <ru@li.org>\n"
@@ -16,7 +16,7 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"X-Generator: KBabel 1.10.2\n"
-#: ../whois.c:117
+#: ../whois.c:120
#, c-format
msgid ""
"Version %s.\n"
@@ -27,31 +27,31 @@ msgstr ""
"\n"
"Замечания отправляйте на %s.\n"
-#: ../whois.c:164 ../whois.c:224 ../whois.c:230 ../whois.c:237 ../whois.c:243
-#: ../whois.c:270
+#: ../whois.c:167 ../whois.c:227 ../whois.c:233 ../whois.c:240 ../whois.c:246
+#: ../whois.c:277
#, c-format
msgid "Using server %s.\n"
msgstr "Используется сервер %s.\n"
-#: ../whois.c:206
+#: ../whois.c:209
msgid "This TLD has no whois server, but you can access the whois database at"
msgstr ""
"Этот ДВУ не имеет whois-сервера, но можно получить доступ к базе whois на"
-#: ../whois.c:214
+#: ../whois.c:217
msgid "This TLD has no whois server."
msgstr "Этот ДВУ не имеет whois-сервера."
-#: ../whois.c:217
+#: ../whois.c:220
msgid "No whois server is known for this kind of object."
msgstr "Нет whois-сервера для объектов данного вида."
-#: ../whois.c:220
+#: ../whois.c:223
msgid "Unknown AS number or IP network. Please upgrade this program."
msgstr "Неизвестный номер AS или IP-сети. Пожалуйста, обновите программу."
#. XXX should fail if p = 0.0.0.0
-#: ../whois.c:250
+#: ../whois.c:253
#, c-format
msgid ""
"\n"
@@ -62,7 +62,7 @@ msgstr ""
"Запрашивается конечная IPv4-точка %s для IPv6-адреса 6-в-4.\n"
"\n"
-#: ../whois.c:257
+#: ../whois.c:260
#, fuzzy, c-format
msgid ""
"\n"
@@ -73,7 +73,7 @@ msgstr ""
"Запрашивается конечная IPv4-точка %s для IPv6-адреса 6-в-4.\n"
"\n"
-#: ../whois.c:271
+#: ../whois.c:278
#, c-format
msgid ""
"Query string: \"%s\"\n"
@@ -82,7 +82,7 @@ msgstr ""
"Строка запроса: \"%s\"\n"
"\n"
-#: ../whois.c:281
+#: ../whois.c:288
#, c-format
msgid ""
"\n"
@@ -95,16 +95,16 @@ msgstr ""
"Найдено перенаправление на %s.\n"
"\n"
-#: ../whois.c:324 ../whois.c:327
+#: ../whois.c:331 ../whois.c:334
#, c-format
msgid "Cannot parse this line: %s"
msgstr "Невозможно разобрать строку: %s"
-#: ../whois.c:482
+#: ../whois.c:489
msgid "Warning: RIPE flags used with a traditional server."
msgstr "Предупреждение: флаги RIPE используются с традиционным сервером."
-#: ../whois.c:620 ../whois.c:755
+#: ../whois.c:627 ../whois.c:762
msgid ""
"Catastrophic error: disclaimer text has been changed.\n"
"Please upgrade this program.\n"
@@ -112,26 +112,26 @@ msgstr ""
"Катастрофическая ошибка: текст отказа был изменён.\n"
"Пожалуйста, обновите программу.\n"
-#: ../whois.c:796
+#: ../whois.c:814
#, c-format
msgid "Host %s not found."
msgstr "Узел %s не найден."
-#: ../whois.c:806
+#: ../whois.c:824
#, c-format
msgid "%s/tcp: unknown service"
msgstr "%s/tcp: неизвестный сервис"
-#: ../whois.c:827
+#: ../whois.c:899
msgid "Timeout."
msgstr "Задержка."
-#: ../whois.c:833
+#: ../whois.c:905
#, c-format
msgid "Interrupted by signal %d..."
msgstr "Прервано по сигналу %d..."
-#: ../whois.c:1003
+#: ../whois.c:1109
#, c-format
msgid ""
"Usage: whois [OPTION]... OBJECT...\n"
@@ -202,52 +202,57 @@ msgstr ""
" --help отобразить эту помощь и выйти\n"
" --version вывести информацию о версии и выйти\n"
-#: ../mkpasswd.c:76
+#: ../mkpasswd.c:80
#, fuzzy
msgid "standard 56 bit DES-based crypt(3)"
msgstr "\tстандартный 56 битный, базирующийся на DES, алгоритм crypt(3)"
-#: ../mkpasswd.c:148
+#: ../mkpasswd.c:159
#, fuzzy, c-format
msgid "Invalid method '%s'.\n"
msgstr "Неверный номер '%s'.\n"
-#: ../mkpasswd.c:157 ../mkpasswd.c:167
+#: ../mkpasswd.c:168 ../mkpasswd.c:178
#, c-format
msgid "Invalid number '%s'.\n"
msgstr "Неверный номер '%s'.\n"
-#: ../mkpasswd.c:185
+#: ../mkpasswd.c:196
#, c-format
msgid "Try '%s --help' for more information.\n"
msgstr "Выполните '%s --help' для дополнительной информации.\n"
-#: ../mkpasswd.c:225
+#: ../mkpasswd.c:237
#, c-format
msgid "Wrong salt length: %d byte(s) when %d expected.\n"
msgstr "Испорченная длина salt: %d байт(а) при ожидаемой %d.\n"
-#: ../mkpasswd.c:231
+#: ../mkpasswd.c:241
+#, fuzzy, c-format
+msgid "Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"
+msgstr "Испорченная длина salt: %d байт(а) при ожидаемой %d.\n"
+
+#: ../mkpasswd.c:247
#, c-format
msgid "Illegal salt character '%c'.\n"
msgstr "Неверный salt-символ '%c'.\n"
-#: ../mkpasswd.c:269 ../mkpasswd.c:296
+#: ../mkpasswd.c:286 ../mkpasswd.c:313
#, c-format
msgid "Password: "
msgstr "Пароль: "
-#: ../mkpasswd.c:290
+#: ../mkpasswd.c:307
#, c-format
msgid "Illegal password character '0x%hhx'.\n"
msgstr "Неверный символ пароля '0x%hhx'.\n"
-#: ../mkpasswd.c:312
+#: ../mkpasswd.c:329
#, c-format
msgid "Method not supported by crypt(3).\n"
msgstr ""
-#: ../mkpasswd.c:363
+#: ../mkpasswd.c:411
#, c-format
msgid ""
"Usage: mkpasswd [OPTIONS]... [PASSWORD [SALT]]\n"
@@ -258,7 +263,7 @@ msgstr ""
"Кодирует ПАРОЛЬ, используя алгоритм crypt(3).\n"
"\n"
-#: ../mkpasswd.c:366
+#: ../mkpasswd.c:414
#, fuzzy, c-format
msgid ""
" -m, --method=TYPE select method TYPE\n"
@@ -291,7 +296,7 @@ msgstr ""
"\n"
"Замечания отправляйте на %s.\n"
-#: ../mkpasswd.c:394
+#: ../mkpasswd.c:442
#, fuzzy, c-format
msgid "Available methods:\n"
msgstr "Доступные алгоритмы:\n"
diff --git a/tld_serv_list b/tld_serv_list
index e9da14f..f747eea 100644
--- a/tld_serv_list
+++ b/tld_serv_list
@@ -318,7 +318,7 @@
.yt whois.nic.yt
.yu NONE # www.nic.yu
.ac.za whois.ac.za
-.co.za WEB http://whois.co.za/ # whois.coza.net.za is restricted
+.co.za whois.coza.net.za
.gov.za whois.gov.za
#.net.za whois.net.za
.org.za WEB http://www.org.za/ # rwhois.org.za:4321
diff --git a/whois.spec b/whois.spec
index 1b329a1..63032c8 100644
--- a/whois.spec
+++ b/whois.spec
@@ -1,6 +1,6 @@
Summary: Enhanced WHOIS client
Name: whois
-Version: 4.7.32
+Version: 4.7.33
Release: 1
License: GPL
Vendor: Marco d'Itri <md@linux.it>
diff --git a/mkpasswd.c b/mkpasswd.c
index 94cf455..ce5bbdc 100644
--- a/mkpasswd.c
+++ b/mkpasswd.c
@@ -28,13 +28,16 @@
#ifdef HAVE_GETOPT_LONG
#include <getopt.h>
#endif
+#include <fcntl.h>
#include <string.h>
#include <time.h>
#include <sys/types.h>
#ifdef HAVE_XCRYPT
#include <xcrypt.h>
#include <sys/stat.h>
-#include <fcntl.h>
+#endif
+#ifdef HAVE_GETTIMEOFDAY
+#include <sys/time.h>
#endif
/* Application-specific */
@@ -65,43 +68,49 @@ static const char valid_salts[] = "abcdefghijklmnopqrstuvwxyz"
struct crypt_method {
const char *method; /* short name used by the command line option */
const char *prefix; /* salt prefix */
- const unsigned int len; /* salt lenght */
+ const unsigned int minlen; /* minimum salt length */
+ const unsigned int maxlen; /* maximum salt length */
const unsigned int rounds; /* supports a variable number of rounds */
const char *desc; /* long description for the methods list */
};
static const struct crypt_method methods[] = {
- /* method prefix len rounds description */
- { "des", "", 2, 0,
+ /* method prefix minlen, maxlen rounds description */
+ { "des", "", 2, 2, 0,
N_("standard 56 bit DES-based crypt(3)") },
- { "md5", "$1$", 8, 0, "MD5" },
+ { "md5", "$1$", 8, 8, 0, "MD5" },
#if defined FreeBSD
- { "bf", "$2$", 22, 0, "Blowfish (FreeBSD)" },
+ { "bf", "$2$", 22, 22, 0, "Blowfish (FreeBSD)" },
#endif
-#if defined OpenBSD || defined HAVE_XCRYPT
- { "bf", "$2a$", 22, 1, "Blowfish" },
+#if defined OpenBSD || (defined __SVR4 && defined __sun) || defined HAVE_XCRYPT
+ { "bf", "$2a$", 22, 22, 1, "Blowfish" },
#endif
#if defined FreeBSD
- { "nt", "$3$", 0, 0, "NT-Hash" },
+ { "nt", "$3$", 0, 0, 0, "NT-Hash" },
#endif
#if defined HAVE_SHA_CRYPT
/* http://people.redhat.com/drepper/SHA-crypt.txt */
- { "sha-256", "$5$", 16, 1, "SHA-256" },
- { "sha-512", "$6$", 16, 1, "SHA-512" },
+ { "sha-256", "$5$", 8, 16, 1, "SHA-256" },
+ { "sha-512", "$6$", 8, 16, 1, "SHA-512" },
#endif
/* http://www.crypticide.com/dropsafe/article/1389 */
-/* proper support is hard since solaris >= 9 supports pluggable methods
+ /*
+ * Actually the maximum salt length is arbitrary, but Solaris by default
+ * always uses 8 characters:
+ * http://cvs.opensolaris.org/source/xref/onnv/onnv-gate/ \
+ * usr/src/lib/crypt_modules/sunmd5/sunmd5.c#crypt_gensalt_impl
+ */
#if defined __SVR4 && defined __sun
- { "sunmd5", "$md5$", ?, 1, "SunMD5" },
-*/
+ { "sunmd5", "$md5$", 8, 8, 1, "SunMD5" },
+#endif
#if defined HAVE_XCRYPT
- { "sha", "{SHA}", 0, 0, "SHA-1" },
+ { "sha", "{SHA}", 0, 0, 0, "SHA-1" },
#endif
- { NULL, NULL, 0, 0, NULL }
+ { NULL, NULL, 0, 0, 0, NULL }
};
void generate_salt(char *const buf, const unsigned int len);
-void *gather_entropy(const int len);
+void *get_random_bytes(const int len);
void display_help(void);
void display_version(void);
void display_methods(void);
@@ -110,7 +119,8 @@ int main(int argc, char *argv[])
{
int ch, i;
int password_fd = -1;
- unsigned int salt_len = 0;
+ unsigned int salt_minlen = 0;
+ unsigned int salt_maxlen = 0;
unsigned int rounds_support = 0;
const char *salt_prefix = NULL;
const char *salt_arg = NULL;
@@ -140,7 +150,8 @@ int main(int argc, char *argv[])
for (i = 0; methods[i].method != NULL; i++)
if (strcaseeq(methods[i].method, optarg)) {
salt_prefix = methods[i].prefix;
- salt_len = methods[i].len;
+ salt_minlen = methods[i].minlen;
+ salt_maxlen = methods[i].maxlen;
rounds_support = methods[i].rounds;
break;
}
@@ -203,7 +214,8 @@ int main(int argc, char *argv[])
/* default: DES password */
if (!salt_prefix) {
- salt_len = methods[0].len;
+ salt_minlen = methods[0].minlen;
+ salt_maxlen = methods[0].maxlen;
salt_prefix = methods[0].prefix;
}
@@ -219,11 +231,15 @@ int main(int argc, char *argv[])
if (salt_arg) {
unsigned int c = strlen(salt_arg);
- /* XXX: should support methods which support variable-length salts */
- if (c != salt_len) {
- fprintf(stderr,
- _("Wrong salt length: %d byte(s) when %d expected.\n"),
- c, salt_len);
+ if (c < salt_minlen || c > salt_maxlen) {
+ if (salt_minlen == salt_maxlen)
+ fprintf(stderr,
+ _("Wrong salt length: %d byte(s) when %d expected.\n"),
+ c, salt_maxlen);
+ else
+ fprintf(stderr,
+ _("Wrong salt length: %d byte(s) when %d <= n <= %d expected.\n"),
+ c, salt_minlen, salt_maxlen);
exit(1);
}
while (c-- > 0) {
@@ -242,7 +258,7 @@ int main(int argc, char *argv[])
strcat(salt, salt_arg);
} else {
#ifdef HAVE_XCRYPT
- void *entropy = gather_entropy(64);
+ void *entropy = get_random_bytes(64);
salt = crypt_gensalt(salt_prefix, rounds, entropy, 64);
if (!salt) {
@@ -252,11 +268,12 @@ int main(int argc, char *argv[])
free(entropy);
#else
salt = NOFAIL(malloc(strlen(salt_prefix) + strlen(rounds_str)
- + salt_len + 1));
+ + salt_maxlen + 1));
*salt = '\0';
strcat(salt, salt_prefix);
strcat(salt, rounds_str);
- generate_salt(salt + strlen(salt), salt_len);
+ /* XXX the salt length should be random when it can vary */
+ generate_salt(salt + strlen(salt), salt_maxlen);
#endif
}
@@ -318,13 +335,8 @@ int main(int argc, char *argv[])
exit(0);
}
-#ifdef HAVE_XCRYPT
-
-#ifndef RANDOM_DEVICE
-#define RANDOM_DEVICE "/dev/urandom"
-#endif
-
-void* gather_entropy(const int count)
+#ifdef RANDOM_DEVICE
+void* get_random_bytes(const int count)
{
char *buf;
int fd;
@@ -332,31 +344,63 @@ void* gather_entropy(const int count)
buf = NOFAIL(malloc(count));
fd = open(RANDOM_DEVICE, O_RDONLY);
if (fd < 0) {
- perror("open");
+ perror("open(" RANDOM_DEVICE ")");
exit(2);
}
if (read(fd, buf, count) != count) {
- perror("open");
+ if (count < 0)
+ perror("read(" RANDOM_DEVICE ")");
+ else
+ fprintf(stderr, "Short read of %s.\n", RANDOM_DEVICE);
exit(2);
}
close(fd);
return buf;
}
+#endif
-#else
+#ifdef RANDOM_DEVICE
void generate_salt(char *const buf, const unsigned int len)
{
unsigned int i;
+ unsigned char *entropy = get_random_bytes(len * sizeof(unsigned char));
+ for (i = 0; i < len; i++)
+ buf[i] = valid_salts[entropy[i] % (sizeof valid_salts - 1)];
+ buf[i] = '\0';
+}
+
+#else /* RANDOM_DEVICE */
+
+void generate_salt(char *const buf, const unsigned int len)
+{
+ unsigned int i;
+
+# ifdef HAVE_GETTIMEOFDAY
+ struct timeval tv;
+
+ gettimeofday(&tv, NULL);
+ srand(tv.tv_sec ^ tv.tv_usec);
+
+# else /* HAVE_GETTIMEOFDAY */
+# warning "This system lacks a strong enough random numbers generator!"
+
+ /*
+ * The possible values of time over one year are 31536000, which is
+ * two orders of magnitude less than the allowed entropy range (2^32).
+ */
srand(time(NULL) + getpid());
+
+# endif /* HAVE_GETTIMEOFDAY */
+
for (i = 0; i < len; i++)
buf[i] = valid_salts[rand() % (sizeof valid_salts - 1)];
buf[i] = '\0';
}
-#endif
+#endif /* RANDOM_DEVICE */
void display_help(void)
{